==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/RealizacjaReceptaMagazynKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class RealizacjaReceptaMagazynKey extends GenericDPSObject {
    /**
     * REALIZACJA_RECEPTA_MAGAZYN.REALIZACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long realizacjaId;

    /**
     * REALIZACJA_RECEPTA_MAGAZYN.OPERACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long operacjaId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return REALIZACJA_RECEPTA_MAGAZYN.REALIZACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRealizacjaId() {
        return realizacjaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * REALIZACJA_RECEPTA_MAGAZYN.REALIZACJA_ID
     *
     * @param realizacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRealizacjaId(Long realizacjaId) {
        this.realizacjaId = realizacjaId;
    }

    /**
     * @return REALIZACJA_RECEPTA_MAGAZYN.OPERACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOperacjaId() {
        return operacjaId;
    }

    /**
     * REALIZACJA_RECEPTA_MAGAZYN.OPERACJA_ID
     *
     * @param operacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOperacjaId(Long operacjaId) {
        this.operacjaId = operacjaId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RealizacjaReceptaMagazynKey other = (RealizacjaReceptaMagazynKey) that;
        return (this.getRealizacjaId() == null ? other.getRealizacjaId() == null : this.getRealizacjaId().equals(other.getRealizacjaId()))
            && (this.getOperacjaId() == null ? other.getOperacjaId() == null : this.getOperacjaId().equals(other.getOperacjaId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getRealizacjaId() == null) ? 0 : getRealizacjaId().hashCode());
        result = prime * result + ((getOperacjaId() == null) ? 0 : getOperacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", realizacjaId=").append(realizacjaId);
        sb.append(", operacjaId=").append(operacjaId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/RealizacjaReceptaMagazynKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class RealizacjaReceptaMagazynKey extends GenericDPSObject {
    /**
     * REALIZACJA_RECEPTA_MAGAZYN.REALIZACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long realizacjaId;

    /**
     * REALIZACJA_RECEPTA_MAGAZYN.OPERACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long operacjaId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return REALIZACJA_RECEPTA_MAGAZYN.REALIZACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRealizacjaId() {
        return realizacjaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:46
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * REALIZACJA_RECEPTA_MAGAZYN.REALIZACJA_ID
     *
     * @param realizacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRealizacjaId(Long realizacjaId) {
        this.realizacjaId = realizacjaId;
    }

    /**
     * @return REALIZACJA_RECEPTA_MAGAZYN.OPERACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOperacjaId() {
        return operacjaId;
    }

    /**
     * REALIZACJA_RECEPTA_MAGAZYN.OPERACJA_ID
     *
     * @param operacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOperacjaId(Long operacjaId) {
        this.operacjaId = operacjaId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RealizacjaReceptaMagazynKey other = (RealizacjaReceptaMagazynKey) that;
        return (this.getRealizacjaId() == null ? other.getRealizacjaId() == null : this.getRealizacjaId().equals(other.getRealizacjaId()))
            && (this.getOperacjaId() == null ? other.getOperacjaId() == null : this.getOperacjaId().equals(other.getOperacjaId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getRealizacjaId() == null) ? 0 : getRealizacjaId().hashCode());
        result = prime * result + ((getOperacjaId() == null) ? 0 : getOperacjaId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", realizacjaId=").append(realizacjaId);
        sb.append(", operacjaId=").append(operacjaId);
        sb.append("]");
        return sb.toString();
    }
}
